.. _bug_reports:

*************************
Submitting a Bug Report
*************************

If you find or just suspect buggy behavior in Corrfunc, 
please raise an issue on GitHub. Navigate to the 
`Corrfunc Issues page <https://github.com/manodeep/Corrfunc/issues>`_, 
create a new issue with a description of the problem and  
the full Traceback (if applicable), and attach a *bug* label to the issue. 

